// PlayerMovement.ts
import { Node,  _decorator, Component, input, Input, EventKeyboard, KeyCode, Vec2 } from 'cc';
import { PlayerController } from './PlayerController';
const { ccclass, property } = _decorator;

@ccclass('PlayerMovement')
export class PlayerMovement extends Component {
    private moveDirection: Vec2 = new Vec2();
    start() {
        // Lắng nghe sự kiện bàn phím
        input.on(Input.EventType.KEY_DOWN, this.onKeyDown, this);
        input.on(Input.EventType.KEY_UP, this.onKeyUp, this);
    }
    onDestroy() {
        // Hủy lắng nghe sự kiện khi component bị phá hủy
        input.off(Input.EventType.KEY_DOWN, this.onKeyDown, this);
        input.off(Input.EventType.KEY_UP, this.onKeyUp, this);
    }

    onKeyDown(event: EventKeyboard) {
        // console.log("Keydown " + event.keyCode);
        switch(event.keyCode) {
            case KeyCode.KEY_W:
                this.moveDirection.y = 1;
                break;
            case KeyCode.KEY_D:
                this.moveDirection.x = 1;
                break;
            case KeyCode.KEY_S:
                this.moveDirection.y = -1;
                break;
            case KeyCode.KEY_A:
                this.moveDirection.x = -1;
                break;
        }
    }

    onKeyUp(event: EventKeyboard) {
        // console.log("Keyup " + event.keyCode);
        switch(event.keyCode) {
            case KeyCode.KEY_W:
                this.moveDirection.y = 0;
                break;
            case KeyCode.KEY_D:
                this.moveDirection.x = 0;
                break;
            case KeyCode.KEY_S:
                this.moveDirection.y = 0;
                break;
            case KeyCode.KEY_A:
                this.moveDirection.x = 0;
                break;
        }
    }

    protected update(dt: number): void {
        this.moveDirection.normalize(); //speed of cross move = normal move
        // Tính toán giá trị mục tiêu vị trí mới
        const targetPos = this.node.position.add3f(
            this.moveDirection.x * PlayerController.GPlayerModel.moveSpeed * dt,
            this.moveDirection.y * PlayerController.GPlayerModel.moveSpeed * dt,
            0
        );
        // Sử dụng lerp để di chuyển mượt mà đến vị trí mục tiêu
        this.node.setPosition(targetPos);
    }    
    
}
